@@ -1,6 +1,6 @@
 from django.contrib import admin
 
-from .models import ReceiverEmailConfiguration, SenderEmailConfiguration
+from .models import ReceiverEmailConfiguration, SenderEmailConfiguration, EmailConfiguration
 
 
 @admin.register(ReceiverEmailConfiguration)
@@ -11,3 +11,9 @@ class ReceiverEmailConfigurationAdmin(admin.ModelAdmin):
 @admin.register(SenderEmailConfiguration)
 class SenderEmailConfigurationAdmin(admin.ModelAdmin):
     list_display = ('sender_email_address',)
+
+
+@admin.register(EmailConfiguration)
+class EmailConfigurationAdmin(admin.ModelAdmin):
+    list_display = ('SUBJECT',
+                    'LOG_PATH',)
