@@ -1,6 +1,6 @@
 import logging
 from email.mime.application import MIMEApplication
-
+from django.template.loader import render_to_string
 import boto3
 from botocore.exceptions import ClientError
 from django.conf import settings
@@ -45,7 +45,7 @@ def list_email_verified():
     return response['Identities']
 
 
-def send_notifications(email, sender):
+def send_notifications(email, sender, email_configuration):
     """This function sends email of a log file """
 
     logger.info('Sending email to recipients')
@@ -54,24 +54,18 @@ def send_notifications(email, sender):
     SENDER = sender
     # Replace recipient@example.com with a "To" address. If your account
     # is still in the sandbox, this address must be verified.
+
     RECIPIENT = email
     # The subject line for the email.
-    SUBJECT = "New Message From OpenLXP Portal"
+    SUBJECT = email_configuration.SUBJECT
+    LOG_PATH = email_configuration.LOG_PATH
 
     # The full path to the file that will be attached to the email.
-    ATTACHMENT = getattr(settings, "LOG_PATH", None)
+    ATTACHMENT = LOG_PATH
 
     # # The HTML body of the email.
-    BODY_HTML = """\
-       <html>
-       <head></head>
-       <body>
-       <h1>Hello!</h1>
-       <p>Please check the attached file for OpenLXP Notifications</p>
-       </body>
-       </html>
-       """
-
+    BODY_HTML = email_configuration.HTML_File
+    html_message = render_to_string(BODY_HTML)
     # Define the attachment part and encode it using MIMEApplication.
     att = MIMEApplication(open(ATTACHMENT, 'rb').read())
 
@@ -84,7 +78,7 @@ def send_notifications(email, sender):
         try:
             # Provide the contents of the email.
 
-            mail = EmailMessage(SUBJECT, BODY_HTML, SENDER,
+            mail = EmailMessage(SUBJECT, html_message, SENDER,
                                 [each_recipient])
             mail.content_subtype = "html"
             # Add the attachment to the parent container.
